.. autosummary::
   :toctree: generated/
   :template: autodocsumm/module-inherit.rst

   cmomy.reduction
   cmomy.resample
   cmomy.random
   cmomy.convert
   cmomy.compile
   cmomy.confidence_interval
   cmomy.rolling
   cmomy.utils



.. autosummary::
   :toctree: generated/
   :template: autodocsumm/module.rst

   cmomy.core.typing
